==> foundation-ui-components-1.25.0.tgz: package/src/common/modal/stories/NsModal.stories.tsx <==
/* eslint-disable @next/next/no-img-element */
import type { StoryObj, Meta } from '@storybook/react';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import NsModal from '../NsModal';
import { NsButton } from '../../button';
import { Grid, Typography } from '@mui/material';
import { useState } from 'react';
import { NsModalProps } from '../types';
import { NsModalData } from './mock';

type ComponentType = typeof NsModal;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/NsModal',
    component: NsModal,
    decorators: [withCenterDecorator],
    argTypes: {},
    args: {
        ...NsModalData,
    },
} as MetaStory;

const RenderNsModal = (args: NsModalProps) => {
    const [isOpen, setOpen] = useState(false);

    const onModalHandler = () => {
        setOpen(!isOpen);
    };

    return (
        <>
            <NsButton onClick={onModalHandler}>Open Modal</NsButton>
            <NsModal {...args} open={isOpen} handleClose={onModalHandler} />
        </>
    );
};

export const Modal: Story = {
    args: {
        header: {
            ...NsModalData?.header,
            isCloseIcon: false,
        },
    } as NsModalProps,
    render: RenderNsModal,
};

export const WithCloseIcon: Story = {
    render: RenderNsModal,
};
const imageURL =
    'https://www.nuskin.com/content/products/01/55/00/01550014/_jcr_content/fullImage.img.160.160.png.64.64.png';
export const ImageWidthText: Story = {
    args: {
        header: {
            show: true,
            isCloseIcon: true,
        },
        body: {
            show: true,
            children: (
                <Grid container spacing={2}>
                    <Grid xs={6}>
                        <img src={imageURL} alt={'NsImage'} />
                    </Grid>
                    <Grid xs={6} className="p-5">
                        <Typography gutterBottom variant="h5" component="div">
                            Lizard
                        </Typography>
                        <Typography variant="body2" color="text.secondary">
                            Lizards are a widespread group of squamate reptiles, with over 6,000 species, ranging across
                            all continents except Antarctica
                        </Typography>
                    </Grid>
                </Grid>
            ),
        },
        footer: {
            show: false,
        },
    },
    render: RenderNsModal,
};

==> foundation-ui-components-1.30.1.tgz: package/src/common/modal/stories/NsModal.stories.tsx <==
import { ReactElement, useState } from 'react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { Grid, Typography } from '@mui/material';
/* eslint-disable @next/next/no-img-element */
import type { Meta, StoryObj } from '@storybook/react';

import { NsButton } from '../../button';
import NsModal from '../NsModal';
import { NsModalProps } from '../types';
import { NsModalData } from './mock';

type ComponentType = typeof NsModal;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/NsModal',
    component: NsModal,
    decorators: [withCenterDecorator],
    argTypes: {},
    args: {
        ...NsModalData,
    },
} as MetaStory;

const RenderNsModal = (args: NsModalProps): ReactElement => {
    const [isOpen, setOpen] = useState(false);

    const onModalHandler = () => {
        setOpen(!isOpen);
    };

    return (
        <>
            <NsButton onClick={onModalHandler}>Open Modal</NsButton>
            <NsModal {...args} open={isOpen} handleClose={onModalHandler} />
        </>
    );
};

export const Modal: Story = {
    args: {
        header: {
            ...NsModalData?.header,
            isCloseIcon: false,
        },
    } as NsModalProps,
    render: RenderNsModal,
};

export const WithCloseIcon: Story = {
    render: RenderNsModal,
};
const imageURL =
    'https://www.nuskin.com/content/products/01/55/00/01550014/_jcr_content/fullImage.img.160.160.png.64.64.png';
export const ImageWidthText: Story = {
    args: {
        header: {
            show: true,
            isCloseIcon: true,
        },
        body: {
            show: true,
            children: (
                <Grid container spacing={2}>
                    <Grid xs={6}>
                        <img src={imageURL} alt={'NsImage'} />
                    </Grid>
                    <Grid xs={6} className="p-5">
                        <Typography gutterBottom variant="h5" component="div">
                            Lizard
                        </Typography>
                        <Typography variant="body2" color="text.secondary">
                            Lizards are a widespread group of squamate reptiles, with over 6,000 species, ranging across
                            all continents except Antarctica
                        </Typography>
                    </Grid>
                </Grid>
            ) as ReactElement,
        },
        footer: {
            show: false,
        },
    },
    render: RenderNsModal,
};
